@@ -14,7 +14,7 @@
 
 #include "lldb/Host/macosx/Config.h"
 
-#elif defined(__ANDROID_NDK__)
+#elif defined(__ANDROID__)
 
 #include "lldb/Host/android/Config.h"
 
@@ -22,7 +22,8 @@
 
 #include "lldb/Host/linux/Config.h"
 
-#elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__)
+#elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__) ||                   \
+    defined(__OpenBSD__)
 
 #include "lldb/Host/freebsd/Config.h"
 
@@ -30,7 +31,7 @@
 
 #include "lldb/Host/netbsd/Config.h"
 
-#elif defined(__MINGW__) || defined (__MINGW32__)
+#elif defined(__MINGW__) || defined(__MINGW32__)
 
 #include "lldb/Host/mingw/Config.h"
 
