@@ -12,19 +12,17 @@
 
 #include "lldb/Host/posix/HostThreadPosix.h"
 
-#include "llvm/ADT/StringRef.h"
 #include "llvm/ADT/SmallString.h"
+#include "llvm/ADT/StringRef.h"
 
-namespace lldb_private
-{
+namespace lldb_private {
 
-class HostThreadFreeBSD : public HostThreadPosix
-{
-  public:
-    HostThreadFreeBSD();
-    HostThreadFreeBSD(lldb::thread_t thread);
+class HostThreadFreeBSD : public HostThreadPosix {
+public:
+  HostThreadFreeBSD();
+  HostThreadFreeBSD(lldb::thread_t thread);
 
-    static void GetName(lldb::tid_t tid, llvm::SmallVectorImpl<char> &name);
+  static void GetName(lldb::tid_t tid, llvm::SmallVectorImpl<char> &name);
 };
 }
 
