@@ -9,21 +9,17 @@
 
 #include "lldb/Host/ThisThread.h"
 
-#include <pthread.h>
 #include "llvm/ADT/SmallVector.h"
+#include <pthread.h>
 
 using namespace lldb_private;
 
-void
-ThisThread::SetName(llvm::StringRef name)
-{
-#if defined (__APPLE__)
-    ::pthread_setname_np(name.str().c_str());
+void ThisThread::SetName(llvm::StringRef name) {
+#if defined(__APPLE__)
+  ::pthread_setname_np(name.str().c_str());
 #endif
 }
 
-void
-ThisThread::GetName(llvm::SmallVectorImpl<char> &name)
-{
-    // FIXME - implement this.
+void ThisThread::GetName(llvm::SmallVectorImpl<char> &name) {
+  // FIXME - implement this.
 }
